@@ -25,7 +25,7 @@
 #
 
 import re
-import sys, os
+import os
 import tempfile
 import gzip
 import errno
@@ -54,7 +54,7 @@ def _numeric_urgency(u):
 
 
 class ControlStanza:
-    source_version_re = re.compile('^\S+ \((?P<version>.*)\).*')
+    source_version_re = re.compile(r'^\S+ \((?P<version>.*)\).*')
     fields_to_read = [ 'Package', 'Source', 'Version', 'Architecture', 'Status' ]
 
     def __init__(self, s):
@@ -113,7 +113,8 @@ class ControlParser:
 
     def readfile(self, file):
         try:
-            self.stanzas += [ControlStanza(x) for x in open(file, 'r', encoding='utf-8', errors='replace').read().split('\n\n') if x]
+            with open(file, encoding='utf-8', errors='replace') as f:
+                self.stanzas += [ControlStanza(x) for x in f.read().split('\n\n') if x]
         except Exception as ex:
             raise RuntimeError(_("Error processing '%(what)s': %(errmsg)s") %
                                 {'what': file, 'errmsg': str(ex)}) from ex
@@ -125,7 +126,7 @@ class ControlParser:
             self.stanzas.append(ControlStanza(output.decode('utf-8', 'replace')))
         except Exception as ex:
             raise RuntimeError(_("Error processing '%(what)s': %(errmsg)s") %
-                                {'what': file, 'errmsg': str(ex)}) from ex
+                                {'what': deb, 'errmsg': str(ex)}) from ex
 
     def find(self, field, value):
         if field in self.index:
@@ -140,9 +141,9 @@ class ControlParser:
         return None
 
 class ChangelogParser:
-    _changelog_header = re.compile('^\S+ \((?P<version>.*)\) .*;.*urgency=(?P<urgency>\w+).*')
-    _changelog_header_ancient = re.compile('^(\S+ \(?\d.*\)|Old Changelog:|Changes|ChangeLog begins|Mon|Tue|Wed|Thu|Fri|Sat|Sun).*')
-    _changelog_header_emacs = re.compile('(;;\s*)?Local\s+variables.*', re.IGNORECASE)
+    _changelog_header = re.compile(r'^\S+ \((?P<version>.*)\) .*;.*urgency=(?P<urgency>\w+).*')
+    _changelog_header_ancient = re.compile(r'^(\S+ \(?\d.*\)|Old Changelog:|Changes|ChangeLog begins|Mon|Tue|Wed|Thu|Fri|Sat|Sun).*')
+    _changelog_header_emacs = re.compile(r'(;;\s*)?Local\s+variables.*', re.IGNORECASE)
 
     def __init__(self):
         self._entry = ''
@@ -335,7 +336,8 @@ class Package:
         if not fd:
             return None
 
-        entries, urgency = ChangelogParser().parse(fd, since_version)
+        with fd:
+            entries, urgency = ChangelogParser().parse(fd, since_version)
 
         if urgency is None:
             return None # not a Debian changelog file
